@@ -155,7 +155,7 @@ def get_service_status_message(service_status_url: str) -> Optional[str]:
 
 class TreebeardConfig(BaseModel):
     notebook: str = "main.ipynb"
-    output_dirs: Tuple[str, ...] = tuple("output")
+    output_dirs: Tuple[str, ...] = tuple(["output"])
     ignore: Tuple[str, ...] = ()
     secret: Tuple[str, ...] = ()
 
