@@ -61,8 +61,7 @@ def save_artifacts():
 
 def run():
     for output_dir in treebeard_config.output_dirs:
-        if not os.path.exists(output_dir):
-            os.makedirs(output_dir)
+        os.makedirs(output_dir, exist_ok=True)
     set_interval(save_artifacts, 10)
     try:
         path, notebook_name = os.path.split(treebeard_config.notebook)
